function [prdData, info] = predict_Dipturus_oxyrinchus(par, data, auxData)  
   
  % unpack par, data, auxData
  cPar = parscomp_st(par);
  v2struct(par); v2struct(cPar); v2struct(data); v2struct(auxData); 
  
  %% compute temperature correction factors
  TC = tempcorr(temp.am, T_ref, T_A); kT_M = k_M * TC;

  %% zero-variate data

  % life cycle
  pars_tp = [g; k; l_T; v_Hb; v_Hp];               % compose parameter vector
  [t_p, t_b, l_p, l_b, info] = get_tp(pars_tp, f); % -, scaled times & lengths at f
  
  % birth
  L_b = L_m * l_b;                  % cm, structural length at birth at f
  Lw_b = L_b/ del_M;                % cm, total length at birth at f
  aT_b = t_b/ kT_M;                 % d, age at birth

  % puberty 
  L_p = L_m * l_p;                  % cm, structural length at puberty at f
  Lw_p = L_p/ del_M;                % cm, total length at puberty at f
  Ww_p = L_p^3 * (1 + f * w);       % g, wet weight at puberty

  % ultimate
  l_i = f - l_T;                    % -, scaled ultimate length at f
  L_i = L_m * l_i;                  % cm, ultimate structural length at f
  Lw_i = L_i/ del_M;                % cm, ultimate total length at f
  Ww_i = L_i^3 * (1 + f * w);       % g, ultimate wet weight 
 
  % reproduction
  pars_R = [kap; kap_R; g; k_J; k_M; L_T; v; U_Hb; U_Hp]; % compose parameter vector at T
  RT_i = TC * reprod_rate(L_i, f, pars_R);                % #/d, ultimate reproduction rate at T

  % life span
  pars_tm = [g; l_T; h_a/ k_M^2; s_G];  % compose parameter vector at T_ref
  t_m = get_tm_s(pars_tm, f, l_b);      % -, scaled mean life span at T_ref
  aT_m = t_m/ k_M/ TC;                  % d, mean life span at T
  
  % males
  p_Am_m = z_m * p_M/ kap;             % J/d.cm^2, {p_Am} spec assimilation flux
  E_m_m = p_Am_m/ v;                   % J/cm^3, reserve capacity [E_m]
  g_m = E_G/ (kap* E_m_m);             % -, energy investment ratio
  m_Em_m = y_E_V * E_m_m/ E_G;         % mol/mol, reserve capacity 
  w_m = m_Em_m * w_E/ w_V;             % -, contribution of reserve to weight
  L_mm = v/ k_M/ g_m;                  % cm, max struct length
  pars_tpm = [g_m; k; l_T; v_Hb; v_Hp]; % compose parameter vector
  [t_pm, t_bm, l_pm, l_bm] = get_tp(pars_tpm, f); % -, scaled times & lengths at f
  L_im = f * L_mm; Lw_im = L_im/ del_M; % cm, struct length at ultimate
  L_pm = l_pm * L_mm; Lw_pm = L_pm/ del_M; % cm, total length at puberty    
  Ww_pm = L_pm^3 * (1 + f * w_m);      % g, ultimate wet weight
 
  %% pack to output
  prdData.ab = aT_b;
  prdData.am = aT_m;
  prdData.Lb = Lw_b;
  prdData.Lp = Lw_p;
  prdData.Lpm = Lw_pm;
  prdData.Li = Lw_i;
  prdData.Ri = RT_i;
  
  %% uni-variate data
  % time-length
  f = f_tL;
  pars_lb = [g; k; v_Hb]; % compose parameter vector
  Lw_b = L_m * get_lb(pars_lb, f)/ del_M;
  Lw_i = L_m * (f - l_T)/ del_M;
  rT_B = TC * k_M/ 3/ (1 + f/ g);               % 1/d, von Bert growth rate
  ELw_f = Lw_i - (Lw_i - Lw_b) * exp( - rT_B * tL_f(:,1)); % cm, expected total length at time
  %
  pars_lbm = [g_m; k; v_Hb]; % compose parameter vector
  Lw_bm = L_mm * get_lb(pars_lbm, f)/ del_M;
  Lw_im = L_mm * (f - l_T)/ del_M;
  rT_Bm = TC * k_M/ 3/ (1 + f/ g_m);            % 1/d, von Bert growth rate
  ELw_m = Lw_im - (Lw_im - Lw_bm) * exp( - rT_Bm * tL_m(:,1)); % cm, expected total length at time

  % length - weight
  EWw_f = (LWw_f(:,1)*del_M).^3 * (1 + f_tL * w);
  EWw_m = (LWw_m(:,1)*del_M).^3 * (1 + f_tL * w_m);
  
  %% pack to output
  prdData.tL_f = ELw_f;
  prdData.tL_m = ELw_m;
  prdData.LWw_f = EWw_f;
  prdData.LWw_m = EWw_m;
    